#
# spec file for package python3-prompt_toolkit
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           python3-prompt_toolkit
Version:        1.0.3
Release:        3.1
Summary:        Library for building powerful interactive command lines in Python
License:        BSD-3-Clause
Group:          Development/Languages/Python
Url:            https://github.com/jonathanslenders/python-prompt-toolkit
Source:         https://files.pythonhosted.org/packages/source/p/prompt_toolkit/prompt_toolkit-%{version}.tar.gz
BuildRequires:  python3-devel
BuildRequires:  python3-Pygments
BuildRequires:  python3-pytest
BuildRequires:  python3-six >= 1.9.0
BuildRequires:  python3-wcwidth
Requires:       python3-Pygments
Requires:       python3-six >= 1.9.0
Requires:       python3-wcwidth
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildArch:      noarch

%description
Prompt toolkit is a Library for building powerful interactive command
lines in Python.

%prep
%setup -q -n prompt_toolkit-%{version}

%build
python3 setup.py build

%install
python3 setup.py install --prefix=%{_prefix} --root=%{buildroot}

%check
pushd tests
PYTHONPATH=%{buildroot}%{python3_sitelib} py.test ./

%files
%defattr(-,root,root,-)
%doc AUTHORS.rst CHANGELOG LICENSE README.rst
%doc examples
%{python3_sitelib}/*

%changelog
* Thu Jul 14 2016 toddrme2178@gmail.com
- Add license file and other documentation files.
- Run test suite.
* Sat Jun 25 2016 arun@gmx.de
- update to version 1.0.3:
  * Fixes:
    + Bugfix for Python2 in readline-like completion.
    + Bugfix in readline-like completion visualisation.
  * New features:
    + Added `erase_when_done` parameter to the `Aplication` class.
    (This was required for the bug fixes.)
    + Added (experimental)
    `CommandLineInterface.run_application_generator` method.  (Also
    required for the bug fix.)
* Sat May 28 2016 arun@gmx.de
- update to version 1.0.0:
  * Fixes:
    + Adjust minimum completion menu width to match UIControl and
    Window class.
    + Bugfix regarding weakref in InputProcessor.
    + Fix for pypy3: bug in WeakValueDictionary.
    + Correctly handle '0' key binding in Vi mode.
    + Also load Vi bindings by default in Application if no registry
    has been given.
    + Only go into selection mode if the current buffer is not empty.
    + Close PipeInput after usage.
    + Only use 16 colors in (Emacs) eterm-color.
    + Bugfix in "xP Vi key binding.
    + Bugfix in Vi { and } key binding.
    + Fix: use correct token for Scrollbar in
    MultiColumnCompletionMenuControl.
    + Handle negative values in translate_row_col_to_index.
    + Handle decomposed unicode characters.
    + Fixed Window.always_hide_cursor. (Parameter was ignored.)
    + Fix in zz Vi key binding. (When render info is not available.)
    + Fix in Document.get_cursor_up_position. (When an argument is
    given.)
  * New features:
    + Separated `load_mouse_bindings`.
    + Refactoring/simplification of the key bindings: better use of
    filters and
    + CLI.editing_mode.
    + Added DummyOutput class and a few unit tests that test the whole
    CLI.
    + Use the bisect module in Document._line_start_indexes instead of
    a custom binary search. This should improve the performance.
    + Stay in the same column when doing multiple up/down movements.
  * Visual improvements:
    + Implemented cursorcolumn, cursorline and colorcolumn.
    + Only reserve menu space when `complete_while_typing=True` or
    when there are completions to be displayed.
    + Support for chaining tokens for combined styles. SelectedText
    will now reverse the colors from the highlighting by
    default. Style `Token.SelectedText` to set a fixed
    foreground/background.  Also for SearchMatch, we now use
    combined tokens.
    + Support for dark gray on Windows.
    + Default token for SystemToolbar and SearchToolbar.
    + Display selection also on empty lines.
  * Emacs key bindings improved:
    + Recognize + handle ControlDelete key.
    + Implemented meta-* and control-backslash key bindings.
  * Vi key bindings improved:
    + Handle inclusive and linewise motions properly.
    + Fix g_ motion off by one character, and don't work when cursor
    is in the trailing whitespace part of line.
    + Make a(/a)/i(/i)/... motions. Find enclosing brackets instead of
    the next bracket.
    + Update N%% motion according to vim behaviors.
    + Fix | motion off by one character.
    + ge/gE motions go to end of previous word, not start.
    + Added Vi 'gm' key binding.
    + Implemented 'gq' key binding in Vi mode. (Reshape text.)
    + Vi operator/text object separation for key bindings.
    + Added 'ap' (auto-paragraph) text object.
    + Implemented Vi digraphs. ControlK will now insert a digraph.
    + Implemented vi tilde_operator.
    + Support named registers.
    + Vi < and > key bindings became operators.
    + Text objects and motions are now separate bindings.
    + Improved copy/paste in Vi mode.
  * Backwards-incompatible changes:
    + Don't reset the current buffer anymore by default in
    CommandLineInterface.run(). Passing `reset_current_buffer=True`
    is now required.
    + Renamed MouseEventTypes to MouseEventType for consistency. The
    old name is still valid, but deprecated.
    + Refactoring of Callbacks. All events should now receive one
    argument, which is the sender. (Furter, Callback was renamed to
    Event.) This is mostly used internally.
    + Moved on_invalidate callback from CommandLineInterface to
    Application
    + Renamed `PipeInput.send` to `PipeInput.send_text`. (Old
    deprecated name is still kept as a valid alias.)
    + Renamed SimpleLexer.default_token to SimpleLexer.token. (+
    backwards-compatibility.)
    + Refactoring of the filters: `ViStateFilter` has been
    deprecated. (Should not be used anymore.) Use the filters, as
    defined in prompt_toolkit.filters.
    + `editing_mode` is now a property of `CommandLineInterface`. This
    is replacing the `vi_mode` parameter in `KeyBindingManager`.
    + The default accept_action for the default Buffer in Application
    now becomes IGNORE. This is a much more sensible default. Pass
    RETURN_DOCUMENT to get the previous behaviour,
    + Always expect an EventLoop instance in
    CommandLineInterface. Creating it in __init__ caused a memory
    leak.
* Sun May  8 2016 arun@gmx.de
- specfile:
  * updated source url to files.pythonhosted.org
* Sat Mar 19 2016 arun@gmx.de
- update to version 0.60:
  * Fixes:
    + Fix in Document.paste. (The screen was not updated after an undo
    of a paste.)
    + Don't use deprecated inspect.getargspec on Python 3.
    + Fixed reading input on Windows when input was piped in stdin.
    + Use correct file descriptors for input/output in
    run_system_command.
    + Always correctly split prompt in shortcuts.prompt. (Even when
    multiline=False)
    + Correctly align right prompt to the top when the left prompt
    consists of multiple lines.
    + Correctly use Token.Transparent as default token for a
    TokenListControl.
    + Fix in syntax synchronisation. (Better handle the case when no
    synchronisation point was found.)
    + Send SIGTSTP to the whole process group.
    + Correctly raise on_buffer_changed on all text changes.
    + Fix in regular_languages.GrammarLexer. (Fixes bug in ptipython
    syntax highlighting.)
  * New features:
    + Add support for additional readers to the Win32 event loop.
    + Added on_render event.
    + Carry the weight in layout dimensions to allow stretching.
* Sat Feb 27 2016 arun@gmx.de
- update to version 0.59:
  * Set correct default color on Windows. (Gray instead of high
    intensity gray.)
  * Reverse colors on Windows when foreground/background color have
    not been specified.
  * Correct handling of mouse events for FillControl.
  * Take margin into account when calculating Window height. (Fixes
    bug in multiline prompt.)
  * Handle division by zero in UIContent.get_height_for_text.
* Thu Feb 25 2016 arun@gmx.de
- update to version 0.58:
  * Fixes:
    + Correctly return result for mouse handler in TokenListControl.
    + Bugfix in meta-backspace key binding. (Delete all whitespace
    before the cursor, when there is only whitespace.)
    + Bugfix in Vi gu, gU, g? and g~ key bindings (in selection mode).
    + Correctly restore default console attributes on Windows.
    + Disable bracketed paste support in ConEmu. (This was broken.)
    + When an unknown exception is raised in
    `CommandLineInterface.run()`, don't forget to redraw the CLI.
  * New features:
    + Many performance improvements and better caching. (Especially in
    the `Document` class.)
    + Support for continuation tokens in `shortcuts.prompt` and
    `shortcuts.create_prompt_layout`.
    + Added `shortcuts.print_tokens` function for printing colored
    output.
    + Sound bell when nothing was deleted.
    + Added escape sequences for F1-F5 keys on the Linux console.
    + Improved support for the Linux console. (Switch back to 16
    colors.)
    + Added F13-F24 input codes for xterm.
    + Created prompt_toolkit.token. A custom Token implementation,
    that is compatible with Pygments.token. (This way, Pygments
    becomes an optional dependency. For many use cases, nothing except
    the Token class from Pygments was used, so it was a bit overkill
    to install Pygments for only that.)
    + Refactoring of prompt_toolkit.styles.
    + `Float` objects got a `hide_when_covering_content` option.
    + Implementation of RPROMPT, like ZSH: Added `get_rprompt_tokens`
    to `create_prompt_layout`.
    + Some improvements to the default style.
    + Also handle Ctrl-R and Ctrl-S in Vi mode when searching.
    + Added TabsProcessor: a tool to visualise tabs instead of
    displaying ^I.
    + Give a better error message when trying to run in git-bash.
    + Support for ANSI color names in style dictionaries.
    + Big refactoring of the `Window` and `UIControl` classes. This
    should result in huge performance improvements on big
    inputs. (While first, a document could have 1,000 lines; now it
    can have about 100,000 lines on the same system.)
    The Window and UIControl have been rewritten very much. Rather
    than each time rendering the whole user control, we now only
    have to render the visible part.
    Because of this, many pieces had to be rewritten:
  - UIControls work differently. They return a `UIContent` instance that
    consist of a collection of lines.
  - All processors have been rewritten. (Their API changed as well, because
    they process one line at a time.)
  - Lexers work differently. `Lexer.lex_document` should now return a function
    that returns the tokens for one line. PygmentsLexer has been optimized that
    it becomes 'lazy', and it has optional syntax synchronisation. That means,
    that the lexer doesn't have to start the lexing at the beginning of the
    document. (Which would be slow for big documents.)
  * Backwards-incompatible changes:
    + As mentioned above, the refactoring of `Window` and `UIControl`
    caused many "internal" APIs to change. All custom `UIControl`,
    `Processor` and `Lexer` classes have to be rewritten. However, for
    most applications this should not be an issue. Especially, the
    `shortcuts.prompt` function is backwards-compatible.
    + `wrap_lines` became a property of `Window` instead of
    `BufferControl`.
* Sat Jan 30 2016 arun@gmx.de
- specfile:
  * update copyright year
- update to version 0.57:
  * Made `max_render_postpone_time` configurable. The current default
    was bad. (We should probably always draw the UI once every cycle
    of the event loop.)
- changes from version 0.56:
  * Fix in bracketed paste. It was not correctly enabled for each
    prompt.
- changes from version 0.55:
  * New features:
    + Implemented bracketed paste mode. (This allows much faster
    pasting, as well as pasting without going into paste mode. This
    makes sure that indentation in ptpython for instance is kept
    correctly.)
    + Added support for italic output and blink. (For terminals that
    support it.)
    + Added get_horizontal_scroll, get_vertical_scroll and
    always_hide_cursor parameters to Window.
    + Refactoring of the posix event loop. Better scheduling of all
    tasks/FDs to avoid starvation. (Everything should feel more
    responsive in high CPU situations.)
    + Added get_default_char function to TokenListControl.
    + AppendAutoSuggestion now accepts a token parameter.
    + Support for ansi color names in styles.
    + Accept get_width/get_height parameters in Float.
    + Added Output.write_raw and accept 'raw' parameter in
    CommandLineInterface.stdout_proxy.
    + Better caching of tokens in TokenListControl.
    + Add mouse support to TokenListControl.
    + Display "Window too small" when the window becomes too small.
    + Added 'bell' function to Output.
    + Accept weights in HSplit/VSplit.
    + Added Registry.remove_binding method to dynamically remove key
    bindings.
    + Added focus_on_click parameter to BufferControl.
    + Introduced BufferMapping class as a wrapper around the buffers
    dictionary. This one also contains the focus stack.
    + Improved 'v' and 'V' key bindings. Allow switching between line
    and character selection modes.
    + Added layout.highlighters. A new, much faster way to do
    selection and search highlighting.
    + Make search_state dynamic for key bindings.
    + Added 'sentence' option to WordCompleter.
    + Cache Document.lines for better performance.
    + Implementation of BLOCK selections. (Cut, copy, paste.)
    + Accept a 'reserve_space_for_menu' parameter in the
    shortcuts. (This is an integer.)
    + Support for 24bit true color on vt100 terminals.
    + Added CommandLineInterface.on_invalidate event.
    + Added __version__ to __init__.py.
  * Fixes:
    + Always show cursor in the 'done' state.
    + Allow HSplit to have zero children.
    + Bugfix for handling of backslash on Windows with some non-us
    keyboards. (Ptpython issue #28.)
    + Never render characters outside the visible screen region.
    + Fix in WordCompleter. When case insensitive and input contained
    uppercase.
    + Highlight search match when the cursor is at any position on the
    match. (not just the beginning.)
  * Backwards-incompatible changes:
    (Most changes will probably not have an impact on external applications.)
    + Change in the `Style` API. This allows caching of Attrs in
    renderer and faster rendering.  (Style now has a
    get_attrs_for_token instead of a get_token_to_attributes_dict
    method.)
    + Removed DefaultStyle. Created PygmentsStyle.from_defaults class
    method instead.
    + Removed AbortAction.IGNORE. This was ambiguous.
    + Accept 'cli' parameter in 'walk' and
    'find_window_for_buffer_name'.
    + The focus stack is now stored in BufferMapping.
    + ViStateFilter and KeyBindingManager now accept a get_vi_state
    callable instead of vi_state itself. (This way a key bindings
    registry becomes stateless.)
    + HighlightSearchProcessor and HighlightSelectionProcessor became
    deprecated. (Use highlighters instead.)
* Sat Oct 31 2015 arun@gmx.de
- update to version 0.54:
  * New features:
    + Allow CommandLineInterface to run in any thread.
    + Hide cursor while rendering.
    + Added add_reader/remove_reader methods to EventLoop.
    + Support for 'reverse' style.
    + Redraw more lazy, by using invalidate.
    + Added show_cursor property to Screen.
    + Center or right align text in TokenListControl also when it spans multiple
    lines.
  * Fixes:
    + Bugfix in PathCompleter. (Expanduser issue.)
    + Fix in signal handler.
    + Use utf-8 encoding in Vt100_Output by default.
    + Use correct default token in BufferControl.
    + Fix in ControlL key binding. Use @handle to allow desactivation.
  * Backwards-incompatible changes:
    + Renamed create_default_layout to create_prompt_layout
    + Renamed create_default_application to create_prompt_application
    + Renamed Layout to Container.
    + Renamed CommandLineInterfaces.request_redraw to invalidate.
    + Changed the actual value of SEARCH_BUFFER, DEFAULT_BUFFER, SYSTEM_BUFFER and
    DUMMY_BUFFER.
    + Changed order of keyword arguments of the BufferControl class. "buffer_name"
    now comes first.
    + Removed old pt(i)python code.
* Sun Oct 18 2015 arun@gmx.de
- update to version 0.53:
  * Handling of the insert key in Vi mode.
  * Added 'zt' and 'zb' Vi key bindings.
  * Added delete key binding for deleting selected text.
  * Select word below cursor on double mouse click.
  * Added `wrap_lines` option to TokenListControl.
  * Added `KeyBindingManager.for_prompt`.
  * Fix in rendering output.
  * Reset renderer correctly in run_in_terminal.
  * Only reset buffer when using `AbortAction.RETRY`.
  * Fix in handling of exit (Ctrl-D) key presses.
  * Fix in `CompleteEvent`. Correctly set `completion_requested`.
  * Renamed `ValidationError.index` to `ValidationError.cursor_position`.
  * Renamed `shortcuts.get_input` to `shortcuts.prompt`.
  * Return empty string instead of None in
    `Document.current_char`/`char_before_cursor`.
- changes from version 0.52:
  * Fix in auto suggestion: hide suggestion when accepting input.
- changes from version 0.51:
  * Mouse support. (Scrolling and clicking for vt100 terminals. For Windows only
    clicking.) Both the autocompletion menus and buffer controls respond to
    scolling and clicking.
  * Added auto suggestions. (Like the fish shell.)
  * Stdout proxy become thread safe.
  * Linewrapping can now be disabled, instead we get horizontal scrolling.
  * Line numbering can now be relative. Like the vi 'relativenumber' option.
  * Fixed excessive scrolling in Windows.
  * Bugfix in search highlighting.
  * Copy all words during repetition of Ctrl-W presses.
  * The 'libs' folder has been removed.
  * Fix in MultiColumnCompletionsMenu: don't create very big columns.
  * Disable search by default in KeyBindingManager.
  * Separated abort/exit key bindings. Disabled by default in KeyBindingManager.
  * 'Ignore' became the default on_abort action in `Application`.
  * 'Ignore' became the default accept_action in `Buffer`.
  * The layout processors have been refactored. The API is changed.
  * `SwitchableValidator` has been renamed to `ConditionalValidator`.
  * `WindowRenderInfo` has several incompatible changes.
  * Margins have been refactored completely. Now it's the window that has the
    margin instead of `BufferControl`. Is is both much more performant and
    flexible.
- changes from version 0.50:
  * Leaving of alternate screen on Windows.
- changes from version 0.49:
  * Added MANIFEST.in
  * Better support for multiline prompts in shortcuts.
  * Added Document.set_document method.
  * Added 'default' argument to `shortcuts.create_default_application`.
  * Added `align_center` option for `TokenListControl`.
  * Added optional key bindings for full page navigation. (Moved key bindings
    from pyvim into prompt-toolkit.)
  * Accepts default_char in BufferControl for filling the background.
  * Added InFocusStack filter.
  * Small fix in TokenListControl: use the right Char for aligning.
  * Removed deprecated 'tokens' attribute from GrammarLexer.
- changes from version 0.48:
  * run_in_terminal now returns the result of the called function.
  * Made history attribute of Buffer class public.
  * Added support for sub CommandLineInterfaces.
  * Accept optional vi_state parameter in KeyBindingManager.
  * Pop-up menu positioning. The menu was shown too often above instead of below
    the cursor.
  * Fix in Control-W key binding. When there is only whitespace before the
    cursor, delete the whitespace.
  * Rendering bug fix in open_in_editor: run editor using cli.run_in_terminal.
  * Fix in renderer. Correctly reserve the vertical space as required by the
    layout.
  * Small fix in Margin ABC.
  * Added __iter__ to History ABC.
  * Small bugfix in CommandLineInterface: create correct eventloop when no
    eventloop was given.
  * Never schedule a second repaint operation when a previous was not yet
    executed.
- changes from version 0.47:
  * Added `prompt_toolkit.layout.utils.iter_token_lines`.
  * Allow `None` values on the focus stack.
  * Buffers can be readonly. Added `IsReadOnly` filter.
  * `eager` behaviour for key bindings. When a key binding is eager it will be
    executed as soon as it's matched, even when there is another binding that
    starts with this key sequence.
  * Custom margins for BufferControl.
  * Don't trigger autocompletion on paste.
  * Added `pre_run` parameter to CommandLineInterface.
  * Correct invalidation of BeforeInput and AfterInput.
  * Correctly handle transparancy. (For floats.)
  * Small change in the algorithm to determine Window dimensions: keep in the
    bounds of the Window dimensions.
  * There a now a `Lexer` abstract base class. Every lexer should be an instance
    of that class, and Pygments lexers should be wrapped in a `PygmentsLexer`
    class. `prompt_toolkit.shortcuts` still accepts Pygments lexers directly for
    backwards-compatibilty.
  * BufferControl no longer has a `show_line_numbers` argument. Pass a
    `NumberredMargin` instance instead.
  * The `History` class became an abstract base class and only defines an
    interface. The default history class is now called `InMemoryHistory`.
* Fri Aug 14 2015 toddrme2178@gmail.com
- Initial version
